@@ -116,7 +116,7 @@ bool IOFireWireSBP2Target::start( IOService *provider )
 
 	if( gFast_Start_Symbol == NULL )
 		gFast_Start_Symbol = OSSymbol::withCString("Fast_Start");
-		
+			
     if (IOService::start(provider))
     {
 		IOFireWireController * 	controller = fProviderUnit->getController();
@@ -163,7 +163,7 @@ bool IOFireWireSBP2Target::start( IOService *provider )
     else
         return false;
 
-    FWKLOG( ( "IOFireWireSBP2Target : started\n" ) );
+    FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : started\n", (UInt32)this ) );
     return true;
 }
 
@@ -173,7 +173,7 @@ bool IOFireWireSBP2Target::start( IOService *provider )
 
 void IOFireWireSBP2Target::stop( IOService *provider )
 {
-    FWKLOG( ( "IOFireWireSBP2Target::stop\n" ) );
+    FWKLOG( ( "IOFireWireSBP2Target<0x%08lx>::stop\n", (UInt32)this ) );
 
     IOService::stop(provider);
 }
@@ -184,11 +184,11 @@ void IOFireWireSBP2Target::stop( IOService *provider )
 
 void IOFireWireSBP2Target::free( void )
 {
-	FWKLOG( ( "IOFireWireSBP2Target::free\n" ) );
+	FWKLOG( ( "IOFireWireSBP2Target<0x%08lx>::free\n", (UInt32)this ) );
 
 	if( fIOCriticalSectionCount != 0 )
 	{
-		IOLog( "IOFireWireSBP2Target::free - fIOCriticalSectionCount == %d!\n", fIOCriticalSectionCount );
+		IOLog( "IOFireWireSBP2Target<0x%08lx>::free - fIOCriticalSectionCount == %d!\n", (UInt32)this, fIOCriticalSectionCount );
 	}
 	
 	while( fIOCriticalSectionCount != 0 )
@@ -210,7 +210,7 @@ IOReturn IOFireWireSBP2Target::message( UInt32 type, IOService *nub, void *arg )
 {
     IOReturn res = kIOReturnUnsupported;
 
-    FWKLOG( ("IOFireWireSBP2Target : message 0x%x, arg 0x%08lx\n", type, arg) );
+    FWKLOG( ("IOFireWireSBP2Target<0x%08lx> : message 0x%x, arg 0x%08lx\n", (UInt32)this, type, arg) );
 
     res = IOService::message(type, nub, arg);
     if( kIOReturnUnsupported == res )
@@ -218,17 +218,17 @@ IOReturn IOFireWireSBP2Target::message( UInt32 type, IOService *nub, void *arg )
         switch (type)
         {                
             case kIOMessageServiceIsTerminated:
-                FWKLOG( ( "IOFireWireSBP2Target : kIOMessageServiceIsTerminated\n" ) );
+                FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : kIOMessageServiceIsTerminated\n", (UInt32)this ) );
                 res = kIOReturnSuccess;
                 break;
 
             case kIOMessageServiceIsSuspended:
-                FWKLOG( ( "IOFireWireSBP2Target : kIOMessageServiceIsSuspended\n" ) );
+                FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : kIOMessageServiceIsSuspended\n", (UInt32)this ) );
                 res = kIOReturnSuccess;
                 break;
 
             case kIOMessageServiceIsResumed:
-                FWKLOG( ( "IOFireWireSBP2Target : kIOMessageServiceIsResumed\n" ) );
+                FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : kIOMessageServiceIsResumed\n", (UInt32)this ) );
                 configurePhysicalFilter();
                 res = kIOReturnSuccess;
                 break;
@@ -238,8 +238,12 @@ IOReturn IOFireWireSBP2Target::message( UInt32 type, IOService *nub, void *arg )
         }
     }
 
-	if( type != kIOMessageServiceIsTerminated )
+	if( type != kIOMessageServiceIsTerminated &&
+		type != (UInt32)kIOMessageFWSBP2ReconnectFailed &&
+		type != (UInt32)kIOMessageFWSBP2ReconnectComplete )
+	{
 		messageClients( type, arg );    
+    } 
     
     return res;
 }
@@ -267,7 +271,7 @@ bool IOFireWireSBP2Target::handleOpen( IOService * forClient, IOOptionBits optio
 {
     bool ok = true;
 
-    FWKLOG(( "enter handleOpen fOpenFromLUNCount = %d, fOpenFromTarget = %d\n", fOpenFromLUNCount, fOpenFromTarget ));
+    FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::handleOpen entered fOpenFromLUNCount = %d, fOpenFromTarget = %d\n", (UInt32)this, fOpenFromLUNCount, fOpenFromTarget ));
     
     IOFireWireSBP2LUN * lunClient = OSDynamicCast( IOFireWireSBP2LUN, forClient );
     if( lunClient != NULL )
@@ -284,7 +288,7 @@ bool IOFireWireSBP2Target::handleOpen( IOService * forClient, IOOptionBits optio
             {
                 fOpenFromLUNCount++;
                 ok = IOService::handleOpen( this, options, arg );
-                FWKLOG(( "called open\n" ));
+                FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::handleOpen called open\n", (UInt32)this ));
             }
         }
         else
@@ -307,21 +311,21 @@ bool IOFireWireSBP2Target::handleOpen( IOService * forClient, IOOptionBits optio
             {
                 fOpenFromTarget = true;
                 ok = IOService::handleOpen( forClient, options, arg );
-                FWKLOG(( "called open\n" ));
+                FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::handleOpen called open\n", (UInt32)this ));
             }
         }
         else
             ok = false;   // already open
     }
 
-    FWKLOG(( "exit handleOpen fOpenFromLUNCount = %d, fOpenFromTarget = %d\n", fOpenFromLUNCount, fOpenFromTarget ));
+    FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::handleOpen - exit handleOpen fOpenFromLUNCount = %d, fOpenFromTarget = %d\n", (UInt32)this, fOpenFromLUNCount, fOpenFromTarget ));
     
     return ok;
 }
 
 void IOFireWireSBP2Target::handleClose( IOService * forClient, IOOptionBits options )
 {
-    FWKLOG(( "enter handleClose fOpenFromLUNCount = %d, fOpenFromTarget = %d\n", fOpenFromLUNCount, fOpenFromTarget ));
+    FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::handleClose enter handleClose fOpenFromLUNCount = %d, fOpenFromTarget = %d\n", (UInt32)this, fOpenFromLUNCount, fOpenFromTarget ));
     
     IOFireWireSBP2LUN * lunClient = OSDynamicCast( IOFireWireSBP2LUN, forClient );
     if( lunClient != NULL )
@@ -334,7 +338,7 @@ void IOFireWireSBP2Target::handleClose( IOService * forClient, IOOptionBits opti
             {
                 IOService::handleClose( this, options);
                 fProviderUnit->close(this, options);
-                FWKLOG(( "called close\n" ));
+                FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::handleClose - called close\n", (UInt32)this ));
             }
         }
     }
@@ -345,11 +349,11 @@ void IOFireWireSBP2Target::handleClose( IOService * forClient, IOOptionBits opti
             fOpenFromTarget = false;
             IOService::handleClose(forClient, options);
             fProviderUnit->close(this, options);
-            FWKLOG(( "called close\n" ));
+            FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::handleClose - called close\n", (UInt32)this ));
         }
     }
 
-    FWKLOG(( "exit handleClose fOpenFromLUNCount = %d, fOpenFromTarget = %d\n", fOpenFromLUNCount, fOpenFromTarget ));
+    FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::handleClose - exit handleClose fOpenFromLUNCount = %d, fOpenFromTarget = %d\n", (UInt32)this, fOpenFromLUNCount, fOpenFromTarget ));
 }
 
 //
@@ -392,18 +396,20 @@ void IOFireWireSBP2Target::scanForLUNs( void )
     IOReturn		status = kIOReturnSuccess;
     IOReturn		tempStatus = kIOReturnSuccess;
     
-	UInt32			cmdSpecID 			= 0;
-	UInt32			cmdSet 				= 0;
-	UInt32			vendorID			= 0;	
-	UInt32			softwareRev 		= 0;
-	UInt32			firmwareRev 		= 0;
-	UInt32			lun					= 0;
-	UInt32			devType				= 0;
-	UInt32 			unitCharacteristics = 0;
-	UInt32 			offset 				= 0;
-	UInt32			revision			= 0;
-	bool			fastStartSupported 	= false;
-	UInt32			fastStart			= 0;
+	LUNInfo info;
+
+	info.cmdSpecID 				= 0;
+	info.cmdSet 				= 0;
+	info.vendorID				= 0;
+	info.softwareRev 			= 0;
+	info.firmwareRev 			= 0;
+	info.lun					= 0;
+	info.devType				= 0;
+	info.unitCharacteristics 	= 0;
+	info.managementOffset 		= 0;
+	info.revision				= 0;
+	info.fastStartSupported 	= false;
+	info.fastStart				= 0;
 	
 	//
     // get root directory
@@ -411,7 +417,7 @@ void IOFireWireSBP2Target::scanForLUNs( void )
 
     IOConfigDirectory *		directory;
     
-    IOFireWireDevice *  device;
+    IOFireWireDevice *  device = NULL;
     IOService *		providerService = fProviderUnit->getProvider();
     if( providerService == NULL )
         status = kIOReturnError;
@@ -421,13 +427,13 @@ void IOFireWireSBP2Target::scanForLUNs( void )
         device = OSDynamicCast( IOFireWireDevice, providerService );
         if( device == NULL )
             status = kIOReturnError;
-        FWKLOG( ("IOFireWireSBP2Target : unit = 0x%08lx, provider = 0x%08lx, device = 0x%08lx\n", fProviderUnit, providerService, device) );
+        FWKLOG( ("IOFireWireSBP2Target<0x%08lx> : unit = 0x%08lx, provider = 0x%08lx, device = 0x%08lx\n", (UInt32)this, fProviderUnit, providerService, device) );
     }
     
     if( status == kIOReturnSuccess )
     {
         status = device->getConfigDirectory( directory );
-        FWKLOG( ( "IOFireWireSBP2Target : status = %d\n", status ) );
+        FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : status = %d\n", (UInt32)this, status ) );
     }
     
     //
@@ -435,35 +441,35 @@ void IOFireWireSBP2Target::scanForLUNs( void )
     //
 
     if( status == kIOReturnSuccess )
-        tempStatus = directory->getKeyValue( kConfigModuleVendorIdKey, vendorID );
+        tempStatus = directory->getKeyValue( kConfigModuleVendorIdKey, info.vendorID );
 
 	//
 	// get unit directory
     //
     
     status = fProviderUnit->getConfigDirectory( directory );
-    FWKLOG( ( "IOFireWireSBP2Target : status = %d\n", status ) );
+    FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : status = %d\n", (UInt32)this, status ) );
   	
 	//
 	// find command spec id
 	//
 
     if( status == kIOReturnSuccess )
-        status = directory->getKeyValue( kCmdSpecIDKey, cmdSpecID );
+        status = directory->getKeyValue( kCmdSpecIDKey, info.cmdSpecID );
     
 	//
 	// find command set
 	//
 
     if( status == kIOReturnSuccess )
-        status = directory->getKeyValue( kCmdSetKey, cmdSet );
+        status = directory->getKeyValue( kCmdSetKey, info.cmdSet );
 
 	//
 	// find unit characteristics
 	//
 	
 	if( status == kIOReturnSuccess )
-        status = directory->getKeyValue( kUnitCharacteristicsKey, unitCharacteristics );
+        status = directory->getKeyValue( kUnitCharacteristicsKey, info.unitCharacteristics );
 
 	//
 	// find management agent offset
@@ -471,7 +477,7 @@ void IOFireWireSBP2Target::scanForLUNs( void )
     // for OpenFirmware boot path generation.
 	//
     
-    status = directory->getKeyValue( kManagementAgentOffsetKey, offset );
+    status = directory->getKeyValue( kManagementAgentOffsetKey, info.managementOffset );
     if( status == kIOReturnSuccess )
     {
         IOService *parent = this;
@@ -482,7 +488,7 @@ void IOFireWireSBP2Target::scanForLUNs( void )
         }
         if(parent) {
             char location[9];
-            sprintf(location, "%lx", offset);
+            sprintf(location, "%lx", info.managementOffset);
             attachToParent(parent, gIODTPlane);
             setLocation(location, gIODTPlane);
             setName("sbp-2", gIODTPlane);
@@ -490,24 +496,24 @@ void IOFireWireSBP2Target::scanForLUNs( void )
     }
  
     // failure to find one of the following is not fatal, hence the use of tempStatus
-
+	
 	//
 	// find revision
 	//
 	
 	if( status == kIOReturnSuccess )
-        tempStatus = directory->getKeyValue( kRevisionKey, revision );
+        tempStatus = directory->getKeyValue( kRevisionKey, info.revision );
 
 	//
 	// find fast start info
 	//
 	
-	if( status == kIOReturnSuccess && revision != 0 )
+	if( status == kIOReturnSuccess && info.revision != 0 )
 	{
-		tempStatus = directory->getKeyValue( kFastStartKey, fastStart );
+		tempStatus = directory->getKeyValue( kFastStartKey, info.fastStart );
 		if( tempStatus == kIOReturnSuccess )
 		{
-			fastStartSupported = true;
+			info.fastStartSupported = true;
 		}
 	}
 
@@ -516,17 +522,17 @@ void IOFireWireSBP2Target::scanForLUNs( void )
 	//
     
     if( status == kIOReturnSuccess )
-         tempStatus = directory->getKeyValue( kSoftwareRevKey, softwareRev );
+         tempStatus = directory->getKeyValue( kSoftwareRevKey, info.softwareRev );
 
     //
 	// find firmware rev
 	//
 
     if( status == kIOReturnSuccess )
-        tempStatus = directory->getKeyValue( kFirmwareRevKey, firmwareRev );
+        tempStatus = directory->getKeyValue( kFirmwareRevKey, info.firmwareRev );
 
-     FWKLOG( ( "IOFireWireSBP2Target : status = %d, cmdSpecID = %d, cmdSet = %d, vendorID = %d, softwareRev = %d, firmwareRev = %d\n",
-                             status, cmdSpecID, cmdSet, vendorID, softwareRev, firmwareRev ) );
+     FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : status = %d, cmdSpecID = %d, cmdSet = %d, vendorID = %d, softwareRev = %d, firmwareRev = %d\n",
+                             (UInt32)this, status, info.cmdSpecID, info.cmdSet, info.vendorID, info.softwareRev, info.firmwareRev ) );
 
     //
     // look for luns implemented as immediate values
@@ -540,8 +546,8 @@ void IOFireWireSBP2Target::scanForLUNs( void )
             // get index key
             UInt32 key;
             tempStatus = directory->getIndexEntry( pos, key );
-            FWKLOG( ( "IOFireWireSBP2Target : tempStatus = %d, pos = %d, key = %d\n",
-                             tempStatus, pos, key ) );
+            FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : tempStatus = %d, pos = %d, key = %d\n",
+                             (UInt32)this, tempStatus, pos, key ) );
             
             // if it was the LUN key
             if( tempStatus == kIOReturnSuccess && key >> kConfigEntryKeyValuePhase == kLUNKey )
@@ -550,22 +556,22 @@ void IOFireWireSBP2Target::scanForLUNs( void )
                 tempStatus = directory->getIndexValue( pos, data );
                 if( tempStatus == kIOReturnSuccess )
                 {
-                    lun = data  & 0x0000ffff;
-                    devType = (data & 0x001f0000) >> 16;
+                    info.lun = data  & 0x0000ffff;
+                    info.devType = (data & 0x001f0000) >> 16;
 
-                    FWKLOG( ( "IOFireWireSBP2Target : cmdSpecID = %d, cmdSet = %d, vendorID = %d, softwareRev = %d\n",
-                             cmdSpecID, cmdSet, vendorID, softwareRev ) );
-                    FWKLOG( ( "IOFireWireSBP2Target : firmwareRev = %d, lun = %d, devType = %d\n",
-                             firmwareRev, lun, devType ) );
-					FWKLOG( ( "IOFireWireSBP2Target : unitCharacteristics = %d, managementOffset = %d,\n",
-                             unitCharacteristics, offset ) );
-					FWKLOG( ( "IOFireWireSBP2Target : revision = %d, fastStartSupported = %d, fastStart = 0x%08lx\n",
-                         revision, fastStartSupported, fastStart ) );
+                    FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : cmdSpecID = %d, cmdSet = %d, vendorID = %d, softwareRev = %d\n",
+                             (UInt32)this, info.cmdSpecID, info.cmdSet, info.vendorID, info.softwareRev ) );
+                    FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : firmwareRev = %d, lun = %d, devType = %d\n",
+                             (UInt32)this, info.firmwareRev, info.lun, info.devType ) );
+					FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : unitCharacteristics = %d, managementOffset = %d,\n",
+                             (UInt32)this, info.unitCharacteristics, info.managementOffset ) );
+					FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : revision = %d, fastStartSupported = %d, fastStart = 0x%08lx\n",
+                         (UInt32)this, info.revision, info.fastStartSupported, info.fastStart ) );
 						 
                     // force vendors to use real values, (0, 0) is not legal
-                    if( (cmdSpecID & 0x00ffffff) || (cmdSet & 0x00ffffff) )
+                    if( (info.cmdSpecID & 0x00ffffff) || (info.cmdSet & 0x00ffffff) )
                     {
-                        createLUN( cmdSpecID, cmdSet, vendorID, softwareRev, firmwareRev, lun, devType, unitCharacteristics, offset, fastStartSupported, fastStart );
+                        createLUN( &info );
                     }
                 }
             }
@@ -591,12 +597,12 @@ void IOFireWireSBP2Target::scanForLUNs( void )
 			// find fast start info
 			//
 			
-			if( revision != 0 )
+			if( info.revision != 0 )
 			{
-				tempStatus = directory->getKeyValue( kFastStartKey, fastStart );
+				tempStatus = directory->getKeyValue( kFastStartKey, info.fastStart );
 				if( tempStatus == kIOReturnSuccess )
 				{
-					fastStartSupported = true;
+					info.fastStartSupported = true;
 				}
 			}
 			
@@ -605,20 +611,20 @@ void IOFireWireSBP2Target::scanForLUNs( void )
             tempStatus = lunDirectory->getKeyValue( kLUNKey, lunValue );
             if( tempStatus == kIOReturnSuccess )
             {
-                lun = lunValue  & 0x0000ffff;
-                devType = (lunValue & 0x001f0000) >> 16;
+                info.lun = lunValue  & 0x0000ffff;
+                info.devType = (lunValue & 0x001f0000) >> 16;
 
-                FWKLOG( ( "IOFireWireSBP2Target : cmdSpecID = %d, cmdSet = %d, vendorID = %d, softwareRev = %d\n",
-                         cmdSpecID, cmdSet, vendorID, softwareRev ) );
-                FWKLOG( ( "IOFireWireSBP2Target : firmwareRev = %d, lun = %d, devType = %d\n",
-                         firmwareRev, lun, devType ) );
-				FWKLOG( ( "IOFireWireSBP2Target : revision = %d, fastStartSupported = %d, fastStart = 0x%08lx\n",
-                         revision, fastStartSupported, fastStart ) );
+                FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : cmdSpecID = %d, cmdSet = %d, vendorID = %d, softwareRev = %d\n",
+                         (UInt32)this, info.cmdSpecID, info.cmdSet, info.vendorID, info.softwareRev ) );
+                FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : firmwareRev = %d, lun = %d, devType = %d\n",
+                         (UInt32)this, info.firmwareRev, info.lun, info.devType ) );
+				FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : revision = %d, fastStartSupported = %d, fastStart = 0x%08lx\n",
+                         (UInt32)this, info.revision, info.fastStartSupported, info.fastStart ) );
 						 
                 // force vendors to use real values, (0, 0) is not legal
-                if( (cmdSpecID & 0x00ffffff) || (cmdSet & 0x00ffffff) )
+                if( (info.cmdSpecID & 0x00ffffff) || (info.cmdSet & 0x00ffffff) )
                 {
-                    createLUN( cmdSpecID, cmdSet, vendorID, softwareRev, firmwareRev, lun, devType, unitCharacteristics, offset, fastStartSupported, fastStart );
+				   createLUN( &info );
                 }
             }
         }
@@ -637,41 +643,51 @@ void IOFireWireSBP2Target::scanForLUNs( void )
     {
         // all of these values are 24 bits or less, even though we have specified 32 bits
 
-		prop = OSNumber::withNumber( cmdSpecID, 32 );
+		prop = OSNumber::withNumber( info.cmdSpecID, 32 );
         setProperty( gCommand_Set_Spec_ID_Symbol, prop );
         prop->release();
 
-		prop = OSNumber::withNumber( cmdSet, 32 );
+		prop = OSNumber::withNumber( info.cmdSet, 32 );
         setProperty( gCommand_Set_Symbol, prop );
         prop->release();
  
-        prop = OSNumber::withNumber( vendorID, 32 );
+        prop = OSNumber::withNumber( info.vendorID, 32 );
         setProperty( gModule_Vendor_ID_Symbol, prop );
         prop->release();
  
-        prop = OSNumber::withNumber( softwareRev, 32 );
+        prop = OSNumber::withNumber( info.softwareRev, 32 );
         setProperty( gCommand_Set_Revision_Symbol, prop );
         prop->release();
  
-        prop = OSNumber::withNumber( firmwareRev, 32 );
+        prop = OSNumber::withNumber( info.firmwareRev, 32 );
         setProperty( gFirmware_Revision_Symbol, prop );
         prop->release();
  
-        prop = OSNumber::withNumber( devType, 32 );
+        prop = OSNumber::withNumber( info.devType, 32 );
         setProperty( gDevice_Type_Symbol, prop );
         prop->release();
 
         prop = fProviderUnit->getProperty(gGUID_Symbol);
         if( prop )
             setProperty( gGUID_Symbol, prop );
-        
+ 
+		prop = fProviderUnit->getProperty(gFireWireModel_ID);
+        if( prop )
+			setProperty( gFireWireModel_ID, prop );
+
+		prop = fProviderUnit->getProperty(gFireWireProduct_Name);
+        if( prop )
+            setProperty( gFireWireProduct_Name, prop );
+
+		prop = fProviderUnit->getProperty(gFireWireVendor_Name);
+        if( prop )
+            setProperty( gFireWireVendor_Name, prop );
+			       
         registerService();
     }
 }
 
-IOReturn IOFireWireSBP2Target::createLUN( UInt32 cmdSpecID, UInt32 cmdSet, UInt32 vendorID, UInt32 softwareRev,
-                                          UInt32 firmwareRev, UInt32 lun, UInt32 devType, UInt32 unitCharacteristics,
-										  UInt32 managementOffset, bool fastStartSupported, UInt32 fastStart )
+IOReturn IOFireWireSBP2Target::createLUN( LUNInfo * info )
 
 {
     IOReturn	status = kIOReturnSuccess;
@@ -682,74 +698,47 @@ IOReturn IOFireWireSBP2Target::createLUN( UInt32 cmdSpecID, UInt32 cmdSet, UInt3
 
     if( propTable )
     {
-
-#if 0
-		const OSSymbol * propSymbol;
-
-		////////////////////////////////////////////
-        // make user client sub dictionary
-        OSDictionary * userClient = OSDictionary::withCapacity(2);
-
-        propSymbol = OSSymbol::withCString("A45B8156-B51B-11D4-AB4B-000A277E7234");
-        prop = OSString::withCString("IOFireWireSBP2Lib.plugin");
-        userClient->setObject( propSymbol, prop );
-        prop->release();
-        propSymbol->release();
-
-        propSymbol = OSSymbol::withCString("631F68D2-B9E6-11D4-8147-000A277E7234");
-        prop = OSString::withCString("SBP2SampleDriver.plugin");
-        userClient->setObject( propSymbol, prop );
-        prop->release();
-        propSymbol->release();
-
-
-        ////////////////////////////////////////////
-                
-        propSymbol = OSSymbol::withCString("IOCFPlugInTypes");
-        propTable->setObject( propSymbol, userClient );
-        propSymbol->release();
-#endif        
         // all of these values are 24 bits or less, even though we have specified 32 bits
 
-        prop = OSNumber::withNumber( cmdSpecID, 32 );
+        prop = OSNumber::withNumber( info->cmdSpecID, 32 );
         propTable->setObject( gCommand_Set_Spec_ID_Symbol, prop );
         prop->release();
 
-		prop = OSNumber::withNumber( cmdSet, 32 );
+		prop = OSNumber::withNumber( info->cmdSet, 32 );
         propTable->setObject( gCommand_Set_Symbol, prop );
         prop->release();
 
-		prop = OSNumber::withNumber( vendorID, 32 );
+		prop = OSNumber::withNumber( info->vendorID, 32 );
         propTable->setObject( gModule_Vendor_ID_Symbol, prop );
         prop->release();
   
-        prop = OSNumber::withNumber( softwareRev, 32 );
+        prop = OSNumber::withNumber( info->softwareRev, 32 );
         propTable->setObject( gCommand_Set_Revision_Symbol, prop );
         prop->release();
  
-        prop = OSNumber::withNumber( firmwareRev, 32 );
+        prop = OSNumber::withNumber( info->firmwareRev, 32 );
         propTable->setObject( gFirmware_Revision_Symbol, prop );
         prop->release();
 
-        prop = OSNumber::withNumber( lun, 32 );
+        prop = OSNumber::withNumber( info->lun, 32 );
         propTable->setObject( gIOUnit_Symbol, prop );
         prop->release();
 
-        prop = OSNumber::withNumber( devType, 32 );
+        prop = OSNumber::withNumber( info->devType, 32 );
         propTable->setObject( gDevice_Type_Symbol, prop );
         prop->release();
  
-		prop = OSNumber::withNumber( unitCharacteristics, 32 );
+		prop = OSNumber::withNumber( info->unitCharacteristics, 32 );
         propTable->setObject( gUnit_Characteristics_Symbol, prop );
         prop->release();
 		
-		prop = OSNumber::withNumber( managementOffset, 32 );
+		prop = OSNumber::withNumber(info->managementOffset, 32 );
         propTable->setObject( gManagement_Agent_Offset_Symbol, prop );
         prop->release();
 		
-		if( fastStartSupported )
+		if( info->fastStartSupported )
 		{
-			prop = OSNumber::withNumber( fastStart, 32 );
+			prop = OSNumber::withNumber( info->fastStart, 32 );
 			propTable->setObject( gFast_Start_Symbol, prop );
 			prop->release();
 		}
@@ -757,6 +746,18 @@ IOReturn IOFireWireSBP2Target::createLUN( UInt32 cmdSpecID, UInt32 cmdSet, UInt3
         prop = fProviderUnit->getProperty(gGUID_Symbol);
         if( prop )
             propTable->setObject( gGUID_Symbol, prop );
+ 
+		prop = fProviderUnit->getProperty(gFireWireModel_ID);
+        if( prop )
+            propTable->setObject( gFireWireModel_ID, prop );
+
+		prop = fProviderUnit->getProperty(gFireWireProduct_Name);
+        if( prop )
+            propTable->setObject( gFireWireProduct_Name, prop );
+
+		prop = fProviderUnit->getProperty(gFireWireVendor_Name);
+        if( prop )
+            propTable->setObject( gFireWireVendor_Name, prop );
         
 		//
         // create lun
@@ -776,7 +777,7 @@ IOReturn IOFireWireSBP2Target::createLUN( UInt32 cmdSpecID, UInt32 cmdSet, UInt3
             if( success )
                 newLUN->registerService();
 
-            FWKLOG( ( "IOFireWireSBP2Target : created LUN object - success = %d\n", success ) );
+            FWKLOG( ( "IOFireWireSBP2Target<0x%08lx> : created LUN object - success = %d\n", (UInt32)this, success ) );
 
             if( !success )
                 status = kIOReturnError;
@@ -816,7 +817,8 @@ bool IOFireWireSBP2Target::matchPropertyTable(OSDictionary * table)
 				compareProperty(table, gCommand_Set_Revision_Symbol) &&
 				compareProperty(table, gFirmware_Revision_Symbol) &&
 				compareProperty(table, gDevice_Type_Symbol) &&
-                compareProperty(table, gGUID_Symbol);
+                compareProperty(table, gGUID_Symbol) &&
+                compareProperty(table, gFireWireModel_ID);
 				
     return res;
 }
@@ -825,7 +827,7 @@ void IOFireWireSBP2Target::setTargetFlags( UInt32 flags )
 {
 	fFlags |= flags;
     
-	FWKLOG(( "IOFireWireSBP2Target::setTargetFlags 0x%08lx\n", fFlags ));
+	FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::setTargetFlags 0x%08lx\n", (UInt32)this, fFlags ));
     
     configurePhysicalFilter();
 }
@@ -834,7 +836,7 @@ void IOFireWireSBP2Target::clearTargetFlags( UInt32 flags )
 {
 	fFlags &= ~flags;
     
-	FWKLOG(( "IOFireWireSBP2Target::clearTargetFlags 0x%08lx\n", fFlags ));
+	FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::clearTargetFlags 0x%08lx\n", (UInt32)this, fFlags ));
     
     configurePhysicalFilter();
 }
@@ -893,12 +895,12 @@ void IOFireWireSBP2Target::configurePhysicalFilter( void )
     
     if( disablePhysicalAccess )
     {
-		FWKLOG(( "IOFireWireSBP2Target::configurePhysicalFilter disabling physical access for unit 0x%08lx\n", fProviderUnit ));
+		FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::configurePhysicalFilter disabling physical access for unit 0x%08lx\n", (UInt32)this, fProviderUnit ));
         fProviderUnit->setNodeFlags( kIOFWDisableAllPhysicalAccess );
     }
     else
     {
-		FWKLOG(( "IOFireWireSBP2Target::configurePhysicalFilter enabling physical access for unit 0x%08lx\n", fProviderUnit ));
+		FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::configurePhysicalFilter enabling physical access for unit 0x%08lx\n", (UInt32)this, fProviderUnit ));
         fProviderUnit->clearNodeFlags( kIOFWDisableAllPhysicalAccess );
     }
     
@@ -912,11 +914,11 @@ IOReturn IOFireWireSBP2Target::beginIOCriticalSection( void )
 {
 	IOReturn status = kIOReturnSuccess;
 
-	FWKLOG(( "IOFireWireSBP2Target::beginIOCriticalSection\n" ));
+	FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::beginIOCriticalSection\n", (UInt32)this ));
 	
 	if( fFlags & kIOFWSBP2FailsOnBusResetsDuringIO )
 	{
-		FWKLOG(( "IOFireWireSBP2Target::beginIOCriticalSection fControl->disableSoftwareBusResets()\n" ));
+		FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::beginIOCriticalSection fControl->disableSoftwareBusResets()\n", (UInt32)this ));
 		status = fControl->disableSoftwareBusResets();
 		if( status == kIOReturnSuccess )
 		{
@@ -924,7 +926,7 @@ IOReturn IOFireWireSBP2Target::beginIOCriticalSection( void )
 		}
 	}
 
-	FWKLOG(( "IOFireWireSBP2Target::beginIOCriticalSection status = 0x%08lx\n", (UInt32)status ));
+	FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::beginIOCriticalSection status = 0x%08lx\n", (UInt32)this, (UInt32)status ));
 	
 	return status;
 }
@@ -935,11 +937,11 @@ IOReturn IOFireWireSBP2Target::beginIOCriticalSection( void )
 
 void IOFireWireSBP2Target::endIOCriticalSection( void )
 {
-	FWKLOG(( "IOFireWireSBP2Target::endIOCriticalSection\n" ));
+	FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::endIOCriticalSection\n", (UInt32)this ));
 
 	if( fFlags & kIOFWSBP2FailsOnBusResetsDuringIO )
 	{
-		FWKLOG(( "IOFireWireSBP2Target::endIOCriticalSection fControl->enableSoftwareBusResets()\n" ));
+		FWKLOG(( "IOFireWireSBP2Target<0x%08lx>::endIOCriticalSection fControl->enableSoftwareBusResets()\n", (UInt32)this ));
 		
 		if( fIOCriticalSectionCount != 0 )
 		{
@@ -948,7 +950,7 @@ void IOFireWireSBP2Target::endIOCriticalSection( void )
 		}
 		else
 		{
-			IOLog( "IOFireWireSBP2Target::endIOCriticalSection - fIOCriticalSectionCount == 0!\n" );
+			IOLog( "IOFireWireSBP2Target<0x%08lx>::endIOCriticalSection - fIOCriticalSectionCount == 0!\n", (UInt32)this );
 		}
 	}
 }
