@@ -224,10 +224,6 @@ UInt32 IOFireWireSBP2LibLUN::release( void )
 	{
 		delete this;
     }
-    else if( fRefCount < 0 )
-	{
-        fRefCount = 0;
-	}
 	
 	return retVal;
 }
