@@ -249,10 +249,6 @@ UInt32 IOFireWireSBP2LibMgmtORB::release( void )
 	{
 		delete this;
     }
-    else if( fRefCount < 0 )
-	{
-        fRefCount = 0;
-	}
 	
 	return retVal;
 }
